Skip to contents

Declares the ENEMDU complex survey design using the canonical design variables: primary sampling unit, strata, and expansion factor.

Usage

enemdu_declare_design(
  data,
  ids = "upm",
  strata = "estrato",
  weights = "fexp",
  nest = TRUE,
  lonely_psu = "adjust"
)

Arguments

data

A data frame.

ids

Name of the primary sampling unit variable. Defaults to "upm".

strata

Name of the strata variable. Defaults to "estrato".

weights

Name of the expansion factor variable. Defaults to "fexp".

nest

Logical passed to survey::svydesign().

lonely_psu

Option used by the survey package for lonely PSUs.

Value

A survey.design object.