Skip to contents

Reads the registry that maps common variable names to domain levels. This registry is intentionally editable because variable names may vary across analytical projects.

Usage

enemdu_domain_variable_registry()

Value

A tibble with variable-to-domain mappings.