Skip to contents

Produces inferential KPI estimates for optional bonus variables such as p78 after they have been transformed with enemdu_build_optional_bonuses(). If transformed variables are absent and p78 is present, the function can build optional bonus variables automatically without creating income scenarios.

Usage

enemdu_kpi_optional_bonuses(
  data,
  group_vars = NULL,
  build_if_missing = TRUE,
  registry = enemdu_indicator_registry(),
  ...
)

Arguments

data

A data frame.

group_vars

Optional grouping variables.

build_if_missing

Logical. If TRUE, calls enemdu_build_optional_bonuses() when optional bonus variables are missing.

registry

Indicator registry.

...

Additional arguments passed to enemdu_indicator_estimate().

Value

A tibble of optional bonus KPI estimates.