Reads the metadata registry that defines special missing-value codes, sentinel nonresponse codes, structural skips, and project-internal rules.
Reads the metadata registry that defines special missing-value codes, sentinel nonresponse codes, structural skips, and project-internal rules.