Reads the optional bonus registry. This registry defines bonus variables such
as p78 that are valid for optional transfer analysis but are not included in
the base poverty-income construction by default.
Reads the optional bonus registry. This registry defines bonus variables such
as p78 that are valid for optional transfer analysis but are not included in
the base poverty-income construction by default.