Skip to contents

Produces a representativity report from an estimate table generated by enemdu_indicator_estimate() or the enemdu_survey_*() functions. The report combines:

Usage

enemdu_representativity_report(
  estimate,
  survey_type = NULL,
  domain_level = NULL,
  domain_var = NULL,
  group_vars = NULL,
  strict_domain = FALSE,
  ...
)

Arguments

estimate

A data frame of estimates or a numeric estimate.

survey_type

Optional survey type.

domain_level

Optional domain level.

domain_var

Optional domain variable.

group_vars

Optional grouping variables.

strict_domain

Logical. If TRUE, errors when the domain is outside design scope.

...

Additional arguments passed to enemdu_check_representativity() when estimate is numeric.

Value

A tibble with integrated representativity metadata.

Details

  • survey type,

  • design-domain scope,

  • requested domain validation,

  • precision decision,

  • and a final representativity flag.

For backward compatibility, when estimate is numeric, the function delegates to enemdu_check_representativity().