Validate the package variable catalog against an official dictionary
Source:R/official_dictionaries.R
enemdu_validate_catalog_against_official_dictionary.RdCompares variable_catalog.csv with an official ENEMDU dictionary. Aliases
declared in the package catalog are respected, so official names such as
id_hogar may validate the canonical internal variable idhogar.
Usage
enemdu_validate_catalog_against_official_dictionary(
dictionary,
variable_catalog = enemdu_variable_catalog(),
required_core_only = FALSE
)