Reads the package variable catalog. The catalog is intentionally metadata-based so that variable contracts can be audited and extended without hiding rules inside analytical functions.
Reads the package variable catalog. The catalog is intentionally metadata-based so that variable contracts can be audited and extended without hiding rules inside analytical functions.