Produces a compact structured diagnostic summary useful in early pipeline checks. The diagnostic includes survey type, design-variable availability, and representativity scope when the survey type is known.
Produces a compact structured diagnostic summary useful in early pipeline checks. The diagnostic includes survey type, design-variable availability, and representativity scope when the survey type is known.