Validate a microdata file against official dictionaries in a ZIP
Source:R/microdata_dictionary_validation.R
enemdu_validate_microdata_file_against_dictionary_zip.RdReads official dictionaries from a ZIP file, optionally filters by dictionary scope and survey type, then validates a microdata file against the resulting dictionary.
Usage
enemdu_validate_microdata_file_against_dictionary_zip(
data_path,
dictionary_zip_path,
dictionary_file_scope = "persona",
survey_type = NULL,
n_max = NULL,
...
)Arguments
- data_path
Path to a microdata file.
- dictionary_zip_path
Path to a ZIP file containing official dictionary files.
- dictionary_file_scope
Optional dictionary scope filter. Defaults to
"persona".- survey_type
Optional survey type filter.
- n_max
Optional maximum number of microdata rows to read.
- ...
Additional arguments passed to
enemdu_validate_microdata_against_dictionary().