Validate internal contracts against official dictionary core variables
Source:R/official_dictionaries.R
enemdu_validate_official_dictionary_core.RdCompares the core official dictionary registry with the package variable catalog, domain variable registry, and optional bonus registry. This function is designed as an audit layer: it flags mismatches without silently changing package contracts.
Usage
enemdu_validate_official_dictionary_core(
survey_type = NULL,
registry = enemdu_official_dictionary_core_registry(),
variable_catalog = enemdu_variable_catalog(),
domain_variable_registry = enemdu_domain_variable_registry(),
optional_bonus_registry = enemdu_optional_bonus_registry(),
emit = TRUE
)Arguments
- survey_type
Optional survey type filter:
"mensual","trimestral"or"anual".- registry
Official dictionary core registry.
- variable_catalog
Package variable catalog.
- domain_variable_registry
Package domain variable registry.
- optional_bonus_registry
Package optional bonus registry.
- emit
Logical. If
TRUE, emits an informational summary.